==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property connectionRetryInterval Number of seconds to wait before retrying connection to the flash media server if the connection is lost.
 * @property filecacheDuration
 * @property httpTransferMode
 * @property numRetries Number of retry attempts.
 * @property restartDelay Number of seconds to wait until a restart is initiated.
 */
public data class
ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings(
    public val connectionRetryInterval: Int? = null,
    public val filecacheDuration: Int? = null,
    public val httpTransferMode: String? = null,
    public val numRetries: Int? = null,
    public val restartDelay: Int? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings):
            ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings =
            ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings(
                connectionRetryInterval = javaType.connectionRetryInterval().map({ args0 -> args0 }).orElse(null),
                filecacheDuration = javaType.filecacheDuration().map({ args0 -> args0 }).orElse(null),
                httpTransferMode = javaType.httpTransferMode().map({ args0 -> args0 }).orElse(null),
                numRetries = javaType.numRetries().map({ args0 -> args0 }).orElse(null),
                restartDelay = javaType.restartDelay().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property connectionRetryInterval Number of seconds to wait before retrying connection to the flash media server if the connection is lost.
 * @property filecacheDuration
 * @property httpTransferMode
 * @property numRetries Number of retry attempts.
 * @property restartDelay Number of seconds to wait until a restart is initiated.
 */
public data class
ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings(
    public val connectionRetryInterval: Int? = null,
    public val filecacheDuration: Int? = null,
    public val httpTransferMode: String? = null,
    public val numRetries: Int? = null,
    public val restartDelay: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings): ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings =
            ChannelEncoderSettingsOutputGroupOutputGroupSettingsHlsGroupSettingsHlsCdnSettingHlsWebdavSettings(
                connectionRetryInterval = javaType.connectionRetryInterval().map({ args0 -> args0 }).orElse(null),
                filecacheDuration = javaType.filecacheDuration().map({ args0 -> args0 }).orElse(null),
                httpTransferMode = javaType.httpTransferMode().map({ args0 -> args0 }).orElse(null),
                numRetries = javaType.numRetries().map({ args0 -> args0 }).orElse(null),
                restartDelay = javaType.restartDelay().map({ args0 -> args0 }).orElse(null),
            )
    }
}
